# Load and look at the data
training_data = read.csv('dataists_training.csv')
print(head(training_data))
# Let's sort this
training_data = training_data[order(training_data$User, training_data$Package),]
print(head(training_data))

# Fit Maximum Likelihood coefficients
logit_fit <- glm(Installed ~ LogDependencyCount +
				LogSuggestionCount +
				LogImportCount +
				LogViewsIncluding +
				LogPackagesMaintaining +
				CorePackage +
				RecommendedPackage,
		data = training_data,
		family = binomial(link = 'logit'))

###########
# Let's predict for the test set
###########
test_data = read.csv('dataists_test.csv')
predictions = predict(logit_fit, newdata=test_data, type="response")
test_data$Installed = predictions
print(head(test_data[!duplicated(test_data$Package),]))

# What is the predicted probability of a package being installed, if it has no dependencies, no suggestions, no imports, no views...
base_frame = data.frame(LogDependencyCount = c(0),
						LogSuggestionCount = c(0),
						LogImportCount = c(0),
						LogViewsIncluding = c(0),
						LogPackagesMaintaining = c(0),
						CorePackage = c(0),
						RecommendedPackage = c(0)
						)
base_prediction = predict(logit_fit, newdata=base_frame, type="response")
print(base_prediction)
		
# It's the inv.logit of the intercept term
if (!("boot" %in% rownames(installed.packages()))) {
	install.packages("boot", repos = "http://cran.cnr.berkeley.edu/", dependencies=TRUE)
}
require(boot)
intercept_coef = coef(logit_fit)["(Intercept)"]
print(inv.logit(intercept_coef))

###########
# What is the impact of having more packages suggest this package
###########
fit_summary = summary(logit_fit)
print(fit_summary)
# Note the line for LogSuggestionCount: the coefficient is 1.06487, and the p-value is <2e-16
suggestion_coef = coef(logit_fit)["LogSuggestionCount"]
print(suggestion_coef)
# Interpretation
# So having 1 order of magnitude increase in the number of suggestions results in multiplying the odds by 1.06487

# Visualization
potential_suggestions = seq(min(training_data$SuggestionCount), max(training_data$SuggestionCount), by = 1)
average_frame = data.frame(LogDependencyCount = rep(mean(training_data$LogDependencyCount), length(potential_suggestions)),
		LogSuggestionCount = log(1+potential_suggestions),
		LogImportCount = rep(mean(training_data$LogImportCount), length(potential_suggestions)),
		LogViewsIncluding = rep(mean(training_data$LogViewsIncluding), length(potential_suggestions)),
		LogPackagesMaintaining = rep(mean(training_data$LogPackagesMaintaining), length(potential_suggestions)),
		CorePackage = rep(mean(training_data$CorePackage), length(potential_suggestions)),
		RecommendedPackage = rep(mean(training_data$RecommendedPackage), length(potential_suggestions))
)
predicted_install_probability = predict(logit_fit, newdata=average_frame, type="response", se.fit=TRUE)
plot(potential_suggestions,predicted_install_probability$fit,xlab="Suggestions",ylab="Predicted Install Probability",main=c("Predicted impact of having additional suggestions","when holding other predictors constant at mean values"),type="l")
points(potential_suggestions,predicted_install_probability$fit + 1.96*predicted_install_probability$se,type="l",lty=2)
points(potential_suggestions,predicted_install_probability$fit - 1.96*predicted_install_probability$se,type="l",lty=2)

# (Approximate) confidence interval
suggestion_coef = coef(logit_fit)["LogSuggestionCount"]
se = coef(fit_summary)["LogSuggestionCount","Std. Error"]
lower = suggestion_coef - 1.96*se
upper = suggestion_coef + 1.96*se
print(sprintf("95%% CI: %0.02f - %0.02f",lower,upper))




